package com.smartadserver.android.library.mediation;

import java.util.HashMap;

import android.app.Activity;
import android.content.Context;
import android.util.Log;
import android.view.View;

import com.google.android.gms.ads.identifier.AdvertisingIdClient;
import com.motionlead.listeners.MotionleadHelper;
import com.motionlead.motionlead.MotionleadHandler;
import com.smartadserver.android.library.SASBannerView;
import com.smartadserver.android.library.SASInterstitialView;
import com.smartadserver.android.library.controller.mraid.SASMRAIDState;
import com.smartadserver.android.library.ui.SASAdView;
import com.smartadserver.android.library.util.SASUtil;

/**
 * Adapter class for MotionLead SDK
 * @hide
 */
public class SASMotionleadAdapter implements SASMediationSDKAdapter {

	private static final String TAG = "SASMotionleadAdapter";
	
	private static final String PLACEMENT_ID_KEY="placementId";
	private static final String PUBLISHER_ID="publisherId";
	
	MotionleadHandler motionleadHandler;
	private AdRequestHandler adRequestHandler;
	private SASAdView sasAdView = null;


	/*
	 * Implementation of MotionLead helper that forward events to the SAS SDK via the AdRequestHandler
	 */
	private class MotionleadHelperImpl implements MotionleadHelper {

		@Override
		public void onError(String arg0) {
			Log.d(TAG, "MotionLead Ad onError");
            adRequestHandler.adRequestFailed(arg0);

		}

		@Override
		public void onMLClick() {
			Log.d(TAG, "MotionLead Ad onMLClick()");
            adRequestHandler.adWasClicked();

		}

		@Override
		public void onMLDismiss() {
			if (sasAdView != null) {
                sasAdView.executeOnUIThread(new Runnable() {
                    public void run() {
                        sasAdView.close();
                    }
                });
            }
		}

		@Override
		public void onMotionleadLoaded() {
			Log.d(TAG, "MotionLead Ad onMotionleadLoaded");

            if (adRequestHandler != null) {

            	sasAdView.getMRAIDController().setState(SASMRAIDState.DEFAULT);

                boolean proceed = adRequestHandler.adRequestSucceeded();

                if (sasAdView instanceof SASInterstitialView) {
                    if (proceed) {
                        if (sasAdView != null) {
                        	// need to hide close button
    						sasAdView.getMRAIDController().setExpandUseCustomCloseProperty(true);
                        }
                        motionleadHandler.displayAd();
                    }
                }
            }
		}

		@Override
		public void onShow() {
			Log.d(TAG, "MotionLead Ad onShow");
		}
    }

	
	@Override
	public void requestAd(final SASAdView sasAdView, HashMap<String, String> placementParameters, AdRequestHandler adRequestHandler) {

		// abort immediately if the SASAdView is a banner (support for interstitial only)
		if (sasAdView instanceof SASBannerView) {
			adRequestHandler.adRequestFailed("MotionLead mediation is not supported for banner placement, only interstitial");
			return;
		}

		Context viewContext = sasAdView.getContext();
		if (!(viewContext instanceof Activity)) {
			adRequestHandler.adRequestFailed("MotionLead ad mediation requires that the SASInterstitialView be created with an Activity as context parameter");
			return;
		}

		Activity viewActivity = (Activity)sasAdView.getContext();

		String placementID = placementParameters.get(PLACEMENT_ID_KEY);
		String publisherId = placementParameters.get(PUBLISHER_ID);

		// store adRequestHandler and SASADView
		this.adRequestHandler = adRequestHandler;
		this.sasAdView = sasAdView;

		// clean previous ad views
		cleanPreviousMotionLeadSetup();

		// init ad listener if need be
		if (motionleadHandler == null) {
			motionleadHandler = new MotionleadHandler(viewActivity,new MotionleadHelperImpl());
		}

		motionleadHandler.displayAd();

		String advertisingID = "";
		AdvertisingIdClient.Info advertisingIDInfo = SASUtil.getAdvertisingIdClientInfo(null, false);
		if (advertisingIDInfo != null) {
			advertisingID = advertisingIDInfo.getId();
		}
		motionleadHandler.onRemoteAd(publisherId, placementID, advertisingID);
	}


	private void cleanPreviousMotionLeadSetup() {
//		motionleadHandler = null; // ?
	}

	@Override
	public View getAdView() {
		// no View as MotionLead displays ads over the Activity
		return null;
	}

	@Override
	public void destroy() {
		sasAdView = null;
		cleanPreviousMotionLeadSetup();
	}
	
	@Override
	public boolean isSDKAvailable() {
		boolean available = true;
		
		try {
			Class.forName("com.motionlead.motionlead.MotionleadHandler");
		} catch (ClassNotFoundException e) {
			available = false;
		}
		return available;
	}
}
